/**
 * y25 - Visualizing Graphs in 2.5 Dimensions (2005)
 * 
 * Arbeitsbereich: Paralleles Rechnen Prof. Kaufmann
 * Studienarbeit:  Werner Jainek
 * Betreuung:      Nina Lehmann
 *
 */
package y25.base;

import y.base.DataAcceptor;
import y.base.DataProvider;

/**
 * Provides access to data associated with a graph. A graph map can be
 * considered as a map that allows only graphs as keys. The graphs used as keys
 * for the getter/setter methods must belong to the same layered graph.
 * <p>
 * The values bound to the graphs are initialized with Java(TM) default
 * values(null, 0, 0.0, false) upon initialization.
 * 
 * @author Werner Jainek
 */
public interface GraphMap extends DataProvider, DataAcceptor {

	/**
	 * Removes the value stored for the given graph, if present. Returns the
	 * value that was previously stored for the graph, or <code>null</code> if
	 * there was no mapping for that graph. A <code>null</code> return can
	 * also mean that the map previously associated <code>null</code> with the
	 * given graph.
	 */
	public Object remove(Object graph);

	/**
	 * Returns the value bound to the given graph. The value must have been
	 * assiciated to the given graph by a call to
	 * {@link GraphMap#set(Object, Object) set}.
	 * <p>
	 * Returns <code>null</code> if the map contains no mapping for this key.
	 * A return value of <code>null</code> does not necessarily indicate that
	 * the map contains no mapping for the key; it is also possible that the map
	 * explicitly maps the key to <code>null</code>.
	 */
	public Object get(Object graph);

	/**
	 * Returns the boolean value bound to the given graph. The value must have
	 * been assiciated to the given graph by a call to
	 * {@link GraphMap#setBool(Object, boolean) setBool}.
	 * <p>
	 * Returns <code>false</code> if the map contains no mapping for this key.
	 * A return value of <code>false</code> does not necessarily indicate that
	 * the map contains no mapping for the key; it is also possible that the map
	 * explicitly maps the key to <code>false</code>.
	 */
	public boolean getBool(Object graph);

	/**
	 * Returns the double value bound to the given graph. The value must have
	 * been assiciated to the given graph by a call to
	 * {@link GraphMap#setDouble(Object, double) setDouble}.
	 * <p>
	 * Returns <code>0.0</code> if the map contains no mapping for this key. A
	 * return value of <code>0.0</code> does not necessarily indicate that the
	 * map contains no mapping for the key; it is also possible that the map
	 * explicitly maps the key to <code>0.0</code>.
	 */
	public double getDouble(Object graph);

	/**
	 * Returns the integer value bound to the given graph. The value must have
	 * been assiciated to the given graph by a call to
	 * {@link GraphMap#setInt(Object, int) setInt}.
	 * <p>
	 * Returns <code>0</code> if the map contains no mapping for this key. A
	 * return value of <code>0</code> does not necessarily indicate that the
	 * map contains no mapping for the key; it is also possible that the map
	 * explicitly maps the key to <code>0</code>.
	 */
	public int getInt(Object graph);

	/**
	 * Associates the given value to the given graph.
	 */
	public void set(Object graph, Object value);

	/**
	 * Associates the given boolean value to the given graph.
	 */
	public void setBool(Object graph, boolean value);

	/**
	 * Associates the given double value to the given graph.
	 */
	public void setDouble(Object graph, double value);

	/**
	 * Associates the given integer value to the given graph.
	 */
	public void setInt(Object graph, int value);

}
