/**
 * y25 - Visualizing Graphs in 2.5 Dimensions (2005)
 * 
 * Arbeitsbereich: Paralleles Rechnen Prof. Kaufmann
 * Studienarbeit:  Werner Jainek
 * Betreuung:      Nina Lehmann
 *
 */
package y25.base;

import y.base.Graph;
import y.base.Node;

/**
 * A <code>LayerEdge</code> connects two <code>Node</code>s that may reside
 * inside different <code>Graph</code>s but that are all inside the same
 * <code>LayeredGraph</code>.
 * 
 * @author Werner Jainek
 */
public class LayerEdge {

	/**
	 * The layered graph this edge belongs to.
	 */
	private LayeredGraph layeredGraph;

	/**
	 * The source node.
	 */
	private Node sourceNode;

	/**
	 * The target node.
	 */
	private Node targetNode;

	/**
	 * Creates a new layer edge that belongs to the given layered graph. The new
	 * edge <code>e</code> has source node <code>v</code> and target node
	 * <code>w</code>. Both the graph that <code>v</code> and the graph
	 * that <code>w</code> belong to have to belong to the given layered graph
	 * <code>lg</code>. It is allowed that both nodes lie in the same graph -
	 * they can even be identical, thereby creating a layer edge self-loop (as
	 * opposed to a normal self-loop).
	 * <p>
	 * Note that this sole constructor is made protected. This means that users
	 * should never create a layer edge by themselves but use the
	 * {@link LayeredGraph#createLayerEdge} method instead.
	 * 
	 * @param lg
	 *            The layered graph the newly created edge will reside in.
	 * @param v
	 *            The source node of the edge.
	 * @param w
	 *            The target node of the edge.
	 */
	protected LayerEdge(LayeredGraph lg, Node v, Node w) {
		layeredGraph = lg;
		sourceNode = v;
		targetNode = w;
	}

	/**
	 * Returns the layered graph this layer edge belongs to.
	 */
	public LayeredGraph getLayeredGraph() {
		return layeredGraph;
	}

	/**
	 * Returns the graph the source node of this layer edge belongs to.
	 */
	public Graph getSourceGraph() {
		return sourceNode.getGraph();
	}

	/**
	 * Returns the graph the target node of this layer edge belongs to.
	 */
	public Graph getTargetGraph() {
		return targetNode.getGraph();
	}

	/**
	 * Returns the source node of this layer edge.
	 */
	public Node source() {
		return sourceNode;
	}

	/**
	 * Returns the target node of this layer edge.
	 */
	public Node target() {
		return targetNode;
	}

}
