/**
 * y25 - Visualizing Graphs in 2.5 Dimensions (2005)
 * 
 * Arbeitsbereich: Paralleles Rechnen Prof. Kaufmann
 * Studienarbeit:  Werner Jainek
 * Betreuung:      Nina Lehmann
 *
 */
package y25.base;

import y.base.YCursor;

/**
 * A cursor interface for iterating over layer edges.
 * <p>
 * The typical use in conjunction with a LayeredGraph instance is as follows:
 * 
 * <pre>
 * LayeredGraph lg; // a layered graph
 * for (LayerEdgeCursor lec = lg.layerEdges(); lec.ok(); lec.next()) {
 * 	LayerEdge le = lec.layerEdge();
 * 	// ... do something with the current layer edge ...
 * }
 * </pre>
 * 
 * @author Werner Jainek
 */
public interface LayerEdgeCursor extends YCursor {

	/**
	 * Returns the layer edge at the current location of the cursor.
	 * 
	 * @return The graph currently pointed to by this cursor.
	 */
	public LayerEdge layerEdge();

	/**
	 * Moves the cursor to the cyclic next element of the underlying sequence.
	 * This is the next element if available, else it is the first element.
	 */
	public void cyclicNext();

	/**
	 * Moves the cursor to the cyclic previous element of the underlying
	 * sequence. This is the previous element if available, else it is the last
	 * element.
	 */
	public void cyclicPrev();
}
