/**
 * y25 - Visualizing Graphs in 2.5 Dimensions
 * 
 * Arbeitsbereich: Paralleles Rechnen Prof. Kaufmann
 * Studienarbeit:  Werner Jainek
 * Betreuung:      Nina Lehmann
 *
 */
package y25.layout;

import y25.graphics.BoundingBox;

/**
 * Provides 2.5D layout information for layers (graphs).
 * 
 * Layout information for a layer is composed of:
 * <ul>
 * <li>a layer's z-position</li>
 * <li>the layer's extent in the (x,y) plane.</li>
 * </ul>
 * The former is provided by the <code>getZ</code> and <code>setZ</code>
 * methods, the latter by the <code>set/getRelativeBoundingBox</code> methods.
 * 
 * @author Werner Jainek
 */
public interface LayerLayout25D {

	/**
	 * Returns the z-position of the layer.
	 */
	public double getZ();

	/**
	 * Sets the z-position of the layer.
	 */
	public void setZ(double z);

	/**
	 * Returns the relative bounding box of the layer. "Relative" here means
	 * relative to the z-position the layer resides at (z values of the bounding
	 * box are therefore 0).
	 */
	public BoundingBox getRealativeBoundingBox();

	/**
	 * Sets the relative bounding box of the layer, thereby determining the
	 * layer's extent in the (x,y) plane (z-values of the bounding box should
	 * therefore be 0).
	 */
	public void setRelativeBoundingBox(BoundingBox bb);
}
