/**
 * y25 - Visualizing Graphs in 2.5 Dimensions
 * 
 * Arbeitsbereich: Paralleles Rechnen Prof. Kaufmann
 * Studienarbeit:  Werner Jainek
 * Betreuung:      Nina Lehmann
 *
 */
package y25.layout;

import y.layout.NodeLayout;
import y25.graphics.BoundingBox;

/**
 * Provides 2.5D layout information for nodes.
 * <p>
 * Additionally to all the 2D layout information that is inherited from
 * <code>NodeLayout</code>, this interface introduces the "depth" of a node,
 * which is its extent in the z-dimension (as opposed to its width and height
 * which are its extent in the x- and y-dimension respectively).
 * 
 * @author Werner Jainek
 */
public interface NodeLayout25D extends NodeLayout {

	/**
	 * Returns the depth of the node, which is its extent in the z-dimension.
	 */
	public double getDepth();

	/**
	 * Sets the depth of the node, which is its extent in the z-dimension.
	 */
	public void setDepth(double depth);

	/**
	 * Sets the size of the node in all three dimensions.
	 */
	public void setSize(double width, double height, double depth);

	/**
	 * Returns the relative bounding box that encompasses the node.
	 * <p>
	 * "Relative" means, that the z-position of the node is treated as the
	 * origin. For example, if a node is located at position (x,y,z) = (4,5,80)
	 * and has a width, height and depth of 4 then the relative bounding box is
	 * defined by the two points <code>bb_min = (2, 3, -2)</code> and
	 * <code>bb_max = (6, 7, 2)</code>. Simply put, the z-position of the
	 * node is just irrelevant.
	 */
	public BoundingBox getRelativeBoundingBox();
}
