/**
 * y25 - Visualizing Graphs in 2.5 Dimensions
 * 
 * Arbeitsbereich: Paralleles Rechnen Prof. Kaufmann
 * Studienarbeit:  Werner Jainek
 * Betreuung:      Nina Lehmann
 *
 */
package y25.view;

import javax.media.opengl.GLAutoDrawable;

import y25.graphics.Camera;
import y25.layout.EdgeLayout25D;

/**
 * Provides a mechanism for rendering edges into an OpenGL context.
 * <p>
 * Note that this interface is not intended to "be used alone". When actually
 * implementing an edge realizer, you have to extend
 * {@link y.view.EdgeRealizer EdgeRealizer} and <em>additionally</em>
 * implement this interface. This is the only way to make sure that the realizer
 * you write works both with the yFiles package <em>and</em> the y25 package.
 * 
 * @author Werner Jainek
 * 
 */
public interface EdgeRealizer25D extends EdgeLayout25D {

	/**
	 * 2D drawing mode for lines.
	 */
	public static final int MODE_2D = 0;

	/**
	 * 3D drawing mode for lines.
	 */
	public static final int MODE_3D = 1;

	/**
	 * Renders the edge this realizer is bound to into the given drawable. If no
	 * edge is bound to the realizer, nothing happens.
	 * <p>
	 * The passed camera is the one that is used to display this edge. It can be
	 * used, for example, to render an edge differently depending on the viewing
	 * position, or to display labels that always face the viewer.
	 */
	public void paintGL(GLAutoDrawable drawable, Camera camera);

	/**
	 * Returns the current display mode for drawing lines. Can be either
	 * <code>EdgeRealizer25D.MODE_2D</code> or
	 * <code>EdgeRealizer25D.MODE_3D</code>.
	 */
	public int getLineDisplayMode();

	/**
	 * Sets the current display mode for drawing lines. Can be either
	 * <code>EdgeRealizer25D.MODE_2D</code> or
	 * <code>EdgeRealizer25D.MODE_3D</code>.
	 */
	public void setLineDisplayMode(int mode);

}
