/**
 * y25 - Visualizing Graphs in 2.5 Dimensions
 * 
 * Arbeitsbereich: Paralleles Rechnen Prof. Kaufmann
 * Studienarbeit:  Werner Jainek
 * Betreuung:      Nina Lehmann
 *
 */
package y25.view;

import javax.media.opengl.GLAutoDrawable;

import y25.graphics.Camera;
import y25.graphics.Point3D;
import y25.layout.NodeLayout25D;

/**
 * Provides a mechanism for rendering nodes into an OpenGL context.
 * <p>
 * Note that this interface is not intended to "be used alone". When actually
 * implementing a node realizer, you have to extend
 * {@link y.view.NodeRealizer NodeRealizer} and <em>additionally</em>
 * implement this interface. This is the only way to make sure that the realizer
 * you write works both with the yFiles package <em>and</em> the y25 package.
 * 
 * @author Werner Jainek
 * 
 */
public interface NodeRealizer25D extends NodeLayout25D {

	/**
	 * Renders the node this realizer belongs to into the given drawable.
	 * <p>
	 * The passed camera is the one that is used to display this node. It can be
	 * used, for example, to render a node differently depending on the viewing
	 * position, or to display labels that always face the viewer.
	 */
	public void paintGL(GLAutoDrawable drawable, Camera camera);

	/**
	 * Intersects a line segment with this node and returns the intersection
	 * point.
	 * <p>
	 * The line segment in three dimensional space is defined by the two points:
	 * <code>source</code> and <code>target</code>. Since a node's
	 * z-position is determined only by the layer it resides in, this
	 * information is not available inside the realizer and therefore has to be
	 * passed in <code>nodeZ</code>.
	 * <p>
	 * This method should return an intersection point only if the passed line
	 * segment actually intersects the node. It should return <code>null</code>,
	 * if the line segment is completely outside or completely inside the node.
	 * If the line segment intersects the node at more than one position, the
	 * first of these intersections has to be returned, i.e. the one that is
	 * closest to <code>source</code>.
	 */
	public Point3D intersect(Point3D source, Point3D target, float nodeZ);

}
